@@ -118,13 +118,13 @@ gchar *GdmSoundOnLoginReadyFile;
 gchar *GdmSoundOnLoginSuccessFile;
 gchar *GdmSoundOnLoginFailureFile;
 gchar *GdmSoundProgram;
-
 gboolean GdmUseCirclesInEntry = FALSE;
 gboolean GdmUseInvisibleInEntry = FALSE;
 
 static gchar *config_file;
 static gboolean used_defaults = FALSE;
 gint greeter_current_delay = 0;
+static gboolean ignore_buttons = FALSE;
 
 /* FIXME: hack */
 GreeterItemInfo *welcome_string_info = NULL;
@@ -134,6 +134,12 @@ extern gboolean require_quarter;
 
 gboolean greeter_probably_login_prompt = FALSE;
 
+void
+greeter_ignore_buttons (gboolean val)
+{
+   ignore_buttons = val;
+}
+
 /* If in random theme mode then grab a random theme from those selected */
 static char *
 get_random_theme ()
@@ -179,9 +185,9 @@ greeter_parse_config (void)
       }
 
     if (ve_string_empty (g_getenv ("GDM_IS_LOCAL"))) {
-	    greeter_Welcome_key = GDM_KEY_REMOTEWELCOME;
-	    greeter_DefaultWelcome_key = GDM_KEY_DEFAULT_REMOTEWELCOME;
-            greeter_DefaultWelcomeBacktest_key = GDM_KEY_DEFAULT_REMOTEWELCOME_BACKTEST;
+	    greeter_Welcome_key = GDM_KEY_REMOTE_WELCOME;
+	    greeter_DefaultWelcome_key = GDM_KEY_DEFAULT_REMOTE_WELCOME;
+            greeter_DefaultWelcomeBacktest_key = GDM_KEY_DEFAULT_REMOTE_WELCOME_BACKTEST;
     } else {
 	    greeter_Welcome_key = GDM_KEY_WELCOME;
 	    greeter_DefaultWelcome_key = GDM_KEY_DEFAULT_WELCOME;
@@ -213,17 +219,17 @@ greeter_parse_config (void)
         g_free (GdmGraphicalThemeDir);
         GdmGraphicalThemeDir = g_strdup (GREETERTHEMEDIR);
       }
-    GdmXineramaScreen = ve_config_get_int (config, GDM_KEY_XINERAMASCREEN);
+    GdmXineramaScreen = ve_config_get_int (config, GDM_KEY_XINERAMA_SCREEN);
     GdmUseCirclesInEntry = ve_config_get_bool (config, GDM_KEY_ENTRY_CIRCLES);
     GdmUseInvisibleInEntry = ve_config_get_bool (config, GDM_KEY_ENTRY_INVISIBLE);
 
     GdmShowXtermFailsafeSession = ve_config_get_bool (config, GDM_KEY_SHOW_XTERM_FAILSAFE);
     GdmShowGnomeFailsafeSession = ve_config_get_bool (config, GDM_KEY_SHOW_GNOME_FAILSAFE);
     GdmShowLastSession = ve_config_get_bool (config, GDM_KEY_SHOW_LAST_SESSION);
-    GdmSessionDir = ve_config_get_string (config, GDM_KEY_SESSDIR);
-    GdmDefaultSession = ve_config_get_string (config, GDM_KEY_DEFAULTSESSION);
-    GdmLocaleFile = ve_config_get_string (config, GDM_KEY_LOCFILE);
-    GdmSystemMenu = ve_config_get_bool (config, GDM_KEY_SYSMENU);
+    GdmSessionDir = ve_config_get_string (config, GDM_KEY_SESSION_DESKTOP_DIR);
+    GdmDefaultSession = ve_config_get_string (config, GDM_KEY_DEFAULT_SESSION);
+    GdmLocaleFile = ve_config_get_string (config, GDM_KEY_LOCALE_FILE);
+    GdmSystemMenu = ve_config_get_bool (config, GDM_KEY_SYSTEM_MENU);
     GdmConfigAvailable = ve_config_get_bool (config, GDM_KEY_CONFIG_AVAILABLE);
     GdmChooserButton = ve_config_get_bool (config, GDM_KEY_CHOOSER_BUTTON);
     GdmHalt = ve_config_get_string (config, GDM_KEY_HALT);
@@ -232,7 +238,7 @@ greeter_parse_config (void)
     GdmConfigurator = ve_config_get_string (config, GDM_KEY_CONFIGURATOR);
     GdmGtkRC = ve_config_get_string (config, GDM_KEY_GTKRC);
     GdmGtkTheme = ve_config_get_string (config, GDM_KEY_GTK_THEME);
-    GdmServAuthDir = ve_config_get_string (config, GDM_KEY_SERVAUTH);
+    GdmServAuthDir = ve_config_get_string (config, GDM_KEY_SERV_AUTHDIR);
     GdmInfoMsgFile = ve_config_get_string (config, GDM_KEY_INFO_MSG_FILE);
     GdmInfoMsgFont = ve_config_get_string (config, GDM_KEY_INFO_MSG_FONT);
 
@@ -252,7 +258,7 @@ greeter_parse_config (void)
     if (GdmDefaultWelcomeBacktest == FALSE) {
             if (strcmp (ve_sure_string (GdmWelcome), GDM_DEFAULT_WELCOME_MSG) == 0)
                 GdmDefaultWelcome == TRUE;
-            else if (strcmp (ve_sure_string (GdmWelcome), GDM_DEFAULT_REMOTEWELCOME_MSG) == 0)
+            else if (strcmp (ve_sure_string (GdmWelcome), GDM_DEFAULT_REMOTE_WELCOME_MSG) == 0)
                 GdmDefaultWelcome == TRUE;
             else
                 GdmDefaultWelcome = FALSE;
@@ -263,18 +269,18 @@ greeter_parse_config (void)
     if (GdmDefaultWelcome && strcmp (greeter_Welcome_key, GDM_KEY_WELCOME) == 0) {
 	    g_free (GdmWelcome);
 	    GdmWelcome = g_strdup (_(GDM_DEFAULT_WELCOME_MSG));
-    } else if (GdmDefaultWelcome && strcmp (greeter_Welcome_key, GDM_KEY_REMOTEWELCOME) == 0) {
+    } else if (GdmDefaultWelcome && strcmp (greeter_Welcome_key, GDM_KEY_REMOTE_WELCOME) == 0) {
 	    g_free (GdmWelcome);
-	    GdmWelcome = g_strdup (_(GDM_DEFAULT_REMOTEWELCOME_MSG));
+	    GdmWelcome = g_strdup (_(GDM_DEFAULT_REMOTE_WELCOME_MSG));
     }
 
     GdmTimedLoginEnable = ve_config_get_bool (config, GDM_KEY_TIMED_LOGIN_ENABLE);
-    GdmIncludeAll = ve_config_get_bool (config, GDM_KEY_INCLUDEALL);
+    GdmIncludeAll = ve_config_get_bool (config, GDM_KEY_INCLUDE_ALL);
     GdmInclude = ve_config_get_string (config, GDM_KEY_INCLUDE);
     GdmExclude = ve_config_get_string (config, GDM_KEY_EXCLUDE);
-    GdmMinimalUID = ve_config_get_int (config, GDM_KEY_MINIMALUID);
-    GdmAllowRoot = ve_config_get_bool (config, GDM_KEY_ALLOWROOT);
-    GdmAllowRemoteRoot = ve_config_get_bool (config, GDM_KEY_ALLOWREMOTEROOT);
+    GdmMinimalUID = ve_config_get_int (config, GDM_KEY_MINIMAL_UID);
+    GdmAllowRoot = ve_config_get_bool (config, GDM_KEY_ALLOW_ROOT);
+    GdmAllowRemoteRoot = ve_config_get_bool (config, GDM_KEY_ALLOW_REMOTE_ROOT);
     GdmTimedLoginDelay = ve_config_get_int (config, GDM_KEY_TIMED_LOGIN_DELAY);
 
     /* Note: TimedLogin here is not gotten out of the config
@@ -306,9 +312,9 @@ greeter_parse_config (void)
 
     GdmUse24Clock = gdm_common_select_time_format (config);
 
-    GdmIconMaxWidth = ve_config_get_int (config, GDM_KEY_ICONWIDTH);
-    GdmIconMaxHeight = ve_config_get_int (config, GDM_KEY_ICONHEIGHT);
-    GdmGlobalFaceDir = ve_config_get_string (config, GDM_KEY_FACEDIR);
+    GdmIconMaxWidth = ve_config_get_int (config, GDM_KEY_ICON_WIDTH);
+    GdmIconMaxHeight = ve_config_get_int (config, GDM_KEY_ICON_HEIGHT);
+    GdmGlobalFaceDir = ve_config_get_string (config, GDM_KEY_FACE_DIR);
     GdmDefaultFace = ve_config_get_string (config, GDM_KEY_FACE);
 
     GdmSoundProgram = ve_config_get_string (config, GDM_KEY_SOUND_PROGRAM);
@@ -396,6 +402,7 @@ greeter_ctrl_handler (GIOChannel *source,
 	} else {
 		greeter_probably_login_prompt = FALSE;
 	}
+	greeter_ignore_buttons (FALSE);
 	greeter_item_pam_prompt (tmp, PW_ENTRY_SIZE, TRUE);
 	g_free (tmp);
 	break;
@@ -405,6 +412,7 @@ greeter_ctrl_handler (GIOChannel *source,
 	buf[len-1] = '\0';
 
 	tmp = ve_locale_to_utf8 (buf);
+	greeter_ignore_buttons (FALSE);
 	greeter_item_pam_prompt (tmp, PW_ENTRY_SIZE, FALSE);
 	g_free (tmp);
 	break;
@@ -443,9 +451,8 @@ greeter_ctrl_handler (GIOChannel *source,
 				 GTK_DIALOG_MODAL /* flags */,
 				 GTK_MESSAGE_ERROR,
 				 GTK_BUTTONS_OK,
-				 FALSE /* markup */,
 				 tmp,
-				 /* avoid warning */ "%s", "");
+				 "");
 	g_free (tmp);
 
 	gdm_wm_center_window (GTK_WINDOW (dlg));
@@ -532,6 +539,7 @@ greeter_ctrl_handler (GIOChannel *source,
 
 	printf ("%c\n", STX);
 	fflush (stdout);
+	greeter_ignore_buttons (FALSE);
 	break;
 
     case GDM_QUIT:
@@ -547,12 +555,11 @@ greeter_ctrl_handler (GIOChannel *source,
 					 GTK_DIALOG_MODAL /* flags */,
 					 GTK_MESSAGE_INFO,
 					 GTK_BUTTONS_OK,
-					 FALSE /* markup */,
 					 /* translators:  This is a nice and evil eggie text, translate
 					  * to your favourite currency */
 					 _("Please insert 25 cents "
 					   "to log in."),
-					 /* avoid warning */ "%s", "");
+					 "");
 		gdm_wm_center_window (GTK_WINDOW (dlg));
 
 		gdm_wm_no_login_focus_push ();
@@ -700,24 +707,32 @@ static void
 greeter_action_ok (GreeterItemInfo *info,
                        gpointer         user_data)
 {
-   GreeterItemInfo *entry_info = greeter_lookup_id ("user-pw-entry");
-   if (entry_info && entry_info->item &&
-       GNOME_IS_CANVAS_WIDGET (entry_info->item) &&
-       GTK_IS_ENTRY (GNOME_CANVAS_WIDGET (entry_info->item)->widget))
+   if (ignore_buttons == FALSE)
      {
-       GtkWidget *entry;
-       entry = GNOME_CANVAS_WIDGET (entry_info->item)->widget;
-       greeter_item_pam_login (GTK_ENTRY (entry), entry_info);
-     }
+       GreeterItemInfo *entry_info = greeter_lookup_id ("user-pw-entry");
+       if (entry_info && entry_info->item &&
+           GNOME_IS_CANVAS_WIDGET (entry_info->item) &&
+           GTK_IS_ENTRY (GNOME_CANVAS_WIDGET (entry_info->item)->widget))
+         {
+           GtkWidget *entry;
+           entry = GNOME_CANVAS_WIDGET (entry_info->item)->widget;
+           greeter_ignore_buttons (TRUE);
+           greeter_item_pam_login (GTK_ENTRY (entry), entry_info);
+         }
+    }
 }
 
 static void
 greeter_action_cancel (GreeterItemInfo *info,
                        gpointer         user_data)
 {
-   greeter_item_ulist_disable ();
-   printf ("%c%c%c\n", STX, BEL, GDM_INTERRUPT_CANCEL);
-   fflush (stdout);
+   if (ignore_buttons == FALSE)
+     {
+       greeter_item_ulist_disable ();
+       greeter_ignore_buttons (TRUE);
+       printf ("%c%c%c\n", STX, BEL, GDM_INTERRUPT_CANCEL);
+       fflush (stdout);
+     }
 }
 
 static void
@@ -774,21 +789,24 @@ verify_gdm_version (void)
       (g_getenv ("GDM_IS_LOCAL") != NULL))
     {
       GtkWidget *dialog;
+      gchar *msg;
     
       gdm_wm_init (0);
       gdm_wm_focus_new_windows (TRUE);
     
+      msg =  g_strdup_printf (_("The greeter version (%s) does not match the daemon "
+                                "version.  "
+                                "You have probably just upgraded gdm.  "
+                                "Please restart the gdm daemon or the computer."),
+                              VERSION);
+    
       dialog = ve_hig_dialog_new (NULL /* parent */,
 				  GTK_DIALOG_MODAL /* flags */,
 				  GTK_MESSAGE_ERROR,
 				  GTK_BUTTONS_OK,
-				  FALSE /* markup */,
 				  _("Cannot start the greeter"),
-				  _("The greeter version (%s) does not match the daemon "
-				    "version.\n"
-				    "You have probably just upgraded gdm.\n"
-				    "Please restart the gdm daemon or the computer."),
-				  VERSION);
+				  msg);
+      g_free (msg);
     
       gtk_widget_show_all (dialog);
       gdm_wm_center_window (GTK_WINDOW (dialog));
@@ -806,21 +824,25 @@ verify_gdm_version (void)
       gdm_version == NULL)
     {
       GtkWidget *dialog;
+      gchar *msg;
     
       gdm_wm_init (0);
       gdm_wm_focus_new_windows (TRUE);
     
+      msg = g_strdup_printf (_("The greeter version (%s) does not match the daemon "
+                               "version. "
+                               "You have probably just upgraded gdm. "
+                               "Please restart the gdm daemon or the computer."),
+                             VERSION);
+    
       dialog = ve_hig_dialog_new (NULL /* parent */,
 				  GTK_DIALOG_MODAL /* flags */,
 				  GTK_MESSAGE_WARNING,
 				  GTK_BUTTONS_NONE,
-				  FALSE /* markup */,
 				  _("Cannot start the greeter"),
-				  _("The greeter version (%s) does not match the daemon "
-				    "version.\n"
-				    "You have probably just upgraded gdm.\n"
-				    "Please restart the gdm daemon or the computer."),
-				  VERSION);
+				  msg);
+      g_free (msg);
+			  
       gtk_dialog_add_buttons (GTK_DIALOG (dialog),
 			      _("Reboot"),
 			      RESPONSE_REBOOT,
@@ -851,21 +873,25 @@ verify_gdm_version (void)
 	strcmp (gdm_version, VERSION) != 0)))
     {
       GtkWidget *dialog;
+      gchar *msg;
     
       gdm_wm_init (0);
       gdm_wm_focus_new_windows (TRUE);
     
+      msg = g_strdup_printf (_("The greeter version (%s) does not match the daemon "
+                               "version (%s).  "
+                               "You have probably just upgraded gdm.  "
+                               "Please restart the gdm daemon or the computer."),
+                             VERSION, gdm_version);
+    
       dialog = ve_hig_dialog_new (NULL /* parent */,
 				  GTK_DIALOG_MODAL /* flags */,
 				  GTK_MESSAGE_WARNING,
 				  GTK_BUTTONS_NONE,
-				  FALSE /* markup */,
 				  _("Cannot start the greeter"),
-				  _("The greeter version (%s) does not match the daemon "
-				    "version (%s).\n"
-				    "You have probably just upgraded gdm.\n"
-				    "Please restart the gdm daemon or the computer."),
-				  VERSION, gdm_version);
+				  msg);
+      g_free (msg);
+
       gtk_dialog_add_buttons (GTK_DIALOG (dialog),
 			      _("Restart"),
 			      RESPONSE_RESTART,
@@ -926,17 +952,17 @@ greeter_reread_config (int sig, gpointer data)
 	    strcmp (theme_dir, GdmGraphicalThemeDir) != 0 ||
 	     ! gdm_common_string_same (config, GdmGtkRC, GDM_KEY_GTKRC) ||
 	     ! gdm_common_string_same (config, GdmGtkTheme, GDM_KEY_GTK_THEME) ||
-	     ! gdm_common_int_same (config, GdmXineramaScreen, GDM_KEY_XINERAMASCREEN) ||
+	     ! gdm_common_int_same (config, GdmXineramaScreen, GDM_KEY_XINERAMA_SCREEN) ||
 	     ! gdm_common_bool_same (config, GdmUseCirclesInEntry, GDM_KEY_ENTRY_CIRCLES) ||
 	     ! gdm_common_bool_same (config, GdmUseInvisibleInEntry, GDM_KEY_ENTRY_INVISIBLE) ||
 	     ! gdm_common_bool_same (config, GdmShowXtermFailsafeSession, GDM_KEY_SHOW_XTERM_FAILSAFE) ||
 	     ! gdm_common_bool_same (config, GdmShowGnomeFailsafeSession, GDM_KEY_SHOW_GNOME_FAILSAFE) ||
-	     ! gdm_common_bool_same (config, GdmIncludeAll, GDM_KEY_INCLUDEALL) ||
+	     ! gdm_common_bool_same (config, GdmIncludeAll, GDM_KEY_INCLUDE_ALL) ||
 	     ! gdm_common_string_same (config, GdmInclude, GDM_KEY_INCLUDE) ||
 	     ! gdm_common_string_same (config, GdmExclude, GDM_KEY_EXCLUDE) ||
-	     ! gdm_common_string_same (config, GdmSessionDir, GDM_KEY_SESSDIR) ||
-	     ! gdm_common_string_same (config, GdmLocaleFile, GDM_KEY_LOCFILE) ||
-	     ! gdm_common_bool_same (config, GdmSystemMenu, GDM_KEY_SYSMENU) ||
+	     ! gdm_common_string_same (config, GdmSessionDir, GDM_KEY_SESSION_DESKTOP_DIR) ||
+	     ! gdm_common_string_same (config, GdmLocaleFile, GDM_KEY_LOCALE_FILE) ||
+	     ! gdm_common_bool_same (config, GdmSystemMenu, GDM_KEY_SYSTEM_MENU) ||
 	     ! gdm_common_string_same (config, GdmHalt, GDM_KEY_HALT) ||
 	     ! gdm_common_string_same (config, GdmReboot, GDM_KEY_REBOOT) ||
 	     ! gdm_common_string_same (config, GdmSuspend, GDM_KEY_SUSPEND) ||
@@ -990,7 +1016,7 @@ greeter_reread_config (int sig, gpointer data)
                 if (GdmDefaultWelcomeBacktest == FALSE) {
                         if (strcmp (ve_sure_string (GdmWelcome), GDM_DEFAULT_WELCOME_MSG) == 0)
                                 GdmDefaultWelcome == TRUE;
-                        else if (strcmp (ve_sure_string (GdmWelcome), GDM_DEFAULT_REMOTEWELCOME_MSG) == 0)
+                        else if (strcmp (ve_sure_string (GdmWelcome), GDM_DEFAULT_REMOTE_WELCOME_MSG) == 0)
                                 GdmDefaultWelcome == TRUE;
                         else
                                 GdmDefaultWelcome = FALSE;
@@ -1000,9 +1026,9 @@ greeter_reread_config (int sig, gpointer data)
 			if (strcmp (greeter_Welcome_key, GDM_KEY_WELCOME) == 0) {
 				g_free (GdmWelcome);
 				GdmWelcome = g_strdup (_(GDM_DEFAULT_WELCOME_MSG));
-			} else if (strcmp (greeter_Welcome_key, GDM_KEY_REMOTEWELCOME) == 0) {
+			} else if (strcmp (greeter_Welcome_key, GDM_KEY_REMOTE_WELCOME) == 0) {
 				g_free (GdmWelcome);
-				GdmWelcome = g_strdup (_(GDM_DEFAULT_REMOTEWELCOME_MSG));
+				GdmWelcome = g_strdup (_(GDM_DEFAULT_REMOTE_WELCOME_MSG));
 			}
 
 			if (welcome_string_info != NULL) {
@@ -1104,6 +1130,7 @@ get_theme_file (const char *in, char **theme_dir)
     }
 
   config = ve_config_new (info);
+  g_free (info);
 
   s = ve_config_get_translated_string (config, "GdmGreeterTheme/Greeter");
   if (s == NULL || s[0] == '\0')
@@ -1118,42 +1145,6 @@ get_theme_file (const char *in, char **theme_dir)
   return file;
 }
 
-/* Not to look too shaby on Xinerama setups */
-static void
-setup_background_color (void)
-{
-  GdkColormap *colormap;
-  GdkColor color;
-  VeConfig *config = ve_config_get (config_file);
-  char *bg_color = ve_config_get_string (config, GDM_KEY_BACKGROUNDCOLOR);
-
-  if (bg_color == NULL ||
-      bg_color[0] == '\0' ||
-      ! gdk_color_parse (bg_color, &color))
-    {
-      gdk_color_parse ("#007777", &color);
-    }
-
-  g_free (bg_color);
-
-  colormap = gdk_drawable_get_colormap
-	  (gdk_get_default_root_window ());
-  /* paranoia */
-  if (colormap != NULL)
-    {
-      gboolean success;
-      gdk_error_trap_push ();
-
-      gdk_colormap_alloc_colors (colormap, &color, 1,
-				 FALSE, TRUE, &success);
-      gdk_window_set_background (gdk_get_default_root_window (), &color);
-      gdk_window_clear (gdk_get_default_root_window ());
-
-      gdk_flush ();
-      gdk_error_trap_pop ();
-    }
-}
-
 /* The reaping stuff */
 static time_t last_reap_delay = 0;
 
@@ -1232,6 +1223,8 @@ gdm_event (GSignalInvocationHint *ihint,
 int
 main (int argc, char *argv[])
 {
+  VeConfig *config;
+  char *bg_color;
   struct sigaction hup;
   struct sigaction term;
   sigset_t mask;
@@ -1285,6 +1278,16 @@ main (int argc, char *argv[])
   if (r != 0)
     return r;
 
+  /* Load the background as early as possible so GDM does not leave  */
+  /* the background unfilled.   The cursor should be a watch already */
+  /* but just in case */
+  config   = ve_config_get (config_file);
+  bg_color = ve_config_get_string (config, GDM_KEY_GRAPHICAL_THEME_COLOR);
+  /* If a graphical theme color does not exist fallback to the plain color */
+  if (ve_string_empty (bg_color)) {
+    bg_color = ve_config_get_string (config, GDM_KEY_BACKGROUND_COLOR);
+  }
+  setup_background_color (bg_color);
   greeter_session_init ();
 
   ve_signal_add (SIGHUP, greeter_reread_config, NULL);
@@ -1390,9 +1393,8 @@ main (int argc, char *argv[])
 				    GTK_DIALOG_MODAL /* flags */,
 				    GTK_MESSAGE_ERROR,
 				    GTK_BUTTONS_OK,
-				    FALSE /* markup */,
 				    s,
-				    "%s", (error && error->message) ? error->message : "");
+				    (error && error->message) ? error->message : "");
 	g_free (s);
     
         gtk_widget_show_all (dialog);
@@ -1436,9 +1438,7 @@ main (int argc, char *argv[])
 				  GTK_DIALOG_MODAL /* flags */,
 				  GTK_MESSAGE_ERROR,
 				  GTK_BUTTONS_OK,
-				  FALSE /* markup */,
 				  _("The greeter theme is corrupt"),
-				  "%s",
 				  _("The theme does not contain "
 				    "definition for the username/password "
 				    "entry element."));
@@ -1472,13 +1472,12 @@ main (int argc, char *argv[])
 				  GTK_DIALOG_MODAL /* flags */,
 				  GTK_MESSAGE_ERROR,
 				  GTK_BUTTONS_OK,
-				  FALSE /* markup */,
 				  _("There was an error loading the "
 				    "theme, and the default theme "
 				    "could not be loaded. "
 				    "Attempting to start the "
 				    "standard greeter"),
-				  /* avoid warning */ "%s", "");
+				  "");
     
       gtk_widget_show_all (dialog);
       gdm_wm_center_window (GTK_WINDOW (dialog));
@@ -1495,12 +1494,11 @@ main (int argc, char *argv[])
 				  GTK_DIALOG_MODAL /* flags */,
 				  GTK_MESSAGE_ERROR,
 				  GTK_BUTTONS_OK,
-				  FALSE /* markup */,
 				  _("The GTK+ greeter could not be started.  "
 				    "This display will abort and you may "
 				    "have to login another way and fix the "
 				    "installation of gdm"),
-				  /* avoid warning */ "%s", "");
+				  "");
     
       gtk_widget_show_all (dialog);
       gdm_wm_center_window (GTK_WINDOW (dialog));
@@ -1523,8 +1521,6 @@ main (int argc, char *argv[])
   gtk_window_move (GTK_WINDOW (window), gdm_wm_screen.x, gdm_wm_screen.y);
   gtk_widget_show_now (window);
 
-  setup_background_color ();
-
   /* can it ever happen that it'd be NULL here ??? */
   if G_UNLIKELY (window->window != NULL)
     {
@@ -1546,9 +1542,7 @@ main (int argc, char *argv[])
 				  GTK_DIALOG_MODAL /* flags */,
 				  GTK_MESSAGE_ERROR,
 				  GTK_BUTTONS_OK,
-				  FALSE /* markup */,
 				  _("Session directory is missing"),
-				  "%s",
 				  _("Your session directory is missing or empty!  "
 				    "There are two available sessions you can use, but "
 				    "you should log in and correct the gdm configuration."));
@@ -1573,9 +1567,7 @@ main (int argc, char *argv[])
 				  GTK_DIALOG_MODAL /* flags */,
 				  GTK_MESSAGE_ERROR,
 				  GTK_BUTTONS_OK,
-				  FALSE /* markup */,
 				  _("Configuration is not correct"),
-				  "%s",
 				  _("The configuration file contains an invalid command "
 				    "line for the login dialog, so running the "
 				    "default command.  Please fix your configuration."));
@@ -1602,9 +1594,7 @@ main (int argc, char *argv[])
 				  GTK_DIALOG_MODAL /* flags */,
 				  GTK_MESSAGE_ERROR,
 				  GTK_BUTTONS_OK,
-				  FALSE /* markup */,
 				  _("No configuration was found"),
-				  "%s",
 				  _("The configuration was not found.  GDM is using "
 				    "defaults to run this session.  You should log in "
 				    "and create a configuration file with the GDM "
