@@ -66,7 +66,7 @@ get_dmx_display (const char *display_name,
 	const char *old_authfile;
 
 	old_authfile = getenv ("XAUTHORITY");
-	ve_setenv ("XAUTHORITY", authfile, TRUE);
+	g_setenv ("XAUTHORITY", authfile, TRUE);
 
 	if ((display = XOpenDisplay (display_name)) == NULL)
 		g_printerr (_("Failed to open display \"%s\"\n"), display_name);
@@ -78,7 +78,7 @@ get_dmx_display (const char *display_name,
 		display = NULL;
 	}
 
-	ve_setenv ("XAUTHORITY", old_authfile, TRUE);
+	g_setenv ("XAUTHORITY", old_authfile, TRUE);
 
 	return display;
 }
@@ -99,6 +99,7 @@ main (int argc, char **argv)
 	options_context = g_option_context_new (_("- migrate a backend display from one DMX display to another"));
 	g_option_context_add_main_entries (options_context, options, GETTEXT_PACKAGE);
 	g_option_context_parse (options_context, &argc, &argv, NULL);
+	g_option_context_free (options_context);
 
 	if (to_display == NULL) {
 		g_printerr (_("You must specify a destination DMX display using %s\n"), "--to");
